@@ -66,9 +66,13 @@ applyFunctionToRowPairs <- function(data, fn) {
 
 #' Wrapper for fitted heuristics to generate predictions with rowPairApply.
 #'
-#' One or more fitted heuristics can be passed in.  They must all implement
-#' predictProbInternal.  Users will generally not use the output directly.
+#' A list of fitted heuristics are passed in.  They must all implement
+#' the fn function passed in, and they must all have the same cols_to_fit.
+#' If they differ on these, then group them in separate heuristicsLists.
 #' 
+#' Users will generally not use the output directly-- instead just pass this
+#' into one of the rowPairApply functions.
+#'
 #' @param list_of_fitted_heuristics Normally a list of predictProbInternal
 #'   implementers, e.g. a fitted ttb model.
 #' @param fn The function to be called on the heuristics, which is typically
@@ -79,25 +83,59 @@ applyFunctionToRowPairs <- function(data, fn) {
 #'   Users will generally not use this directly-- rowPairApply will.
 #' 
 #' @examples
-#' ## This is typical usage:
+#' # Use one fitted ttbModel with column 1 as criterion and columns 2,3 as
+#' # cues.
 #' data <- cbind(y=c(30,20,10,5), x1=c(1,1,0,0), x2=c(1,1,0,1))
-#' ttb <- ttbModel(data, 1, c(2:ncol(data)))
+#' ttb <- ttbModel(data, 1, c(2:3))
 #' rowPairApply(data, heuristicsList(list(ttb), predictPairInternal))
-#' ## This outputs ttb's predictions for all 6 row pairs of data.
-#' ## (It has 6 row pairs because 4*2/2 = 6.)  It gets the predictions
-#' ## by calling ttb's predictPairInternal.
+#' # This outputs ttb's predictions for all 6 row pairs of data.
+#' # (It has 6 row pairs because 4*2/2 = 6.)  It gets the predictions
+#' # by calling ttb's predictPairInternal.
+#'
+#' # Use the same fitted ttbModel plus a unit weight model with the same
+#' # criterion and cues.
+#' unit <- unitWeightModel(data, 1, c(2,3))
+#' rowPairApply(data, heuristicsList(list(ttb, unit), predictPairInternal))
+#' # This outputs predictions with column names 'ttbModel' and
+#' # 'unitWeightLinearModel'.
+#'
+#' # Use the same fitted ttbModel plus another ttbModel that has different
+#' # cols_to_fit.  This has to be put in a separate heuristicsList function.
+#' ttb_just_col_3 <- ttbModel(data, 1, c(3), fit_name="ttb3")
+#' rowPairApply(data, heuristicsList(list(ttb), predictPairInternal),
+#'   heuristicsList(list(ttb_just_col_3), predictPairInternal))
+#' # This outputs predictions with column names 'ttbModel' and
+#' # 'ttb3'.
 #'
 #' @seealso
-#' \code{\link{heuristics}} and  \code{\link{heuristicsProb}} for 
-#'   simpler versions of this function.
+#' \code{\link{rowPairApply}} which is what the output of heuristicsList is
+#' normally passed in to.
+#'
+#' @seealso
+#' \code{\link{heuristics}} for a simpler version of this function with more
+#' examples.  It is recommended for most uses.  (It is hard-coded for
+#' fn=predictPairInternal, which is what most people use.)
+#'
+#' @seealso
+#'\code{\link{heuristicsProb}} for a version of this function tailored for
+#' predictProbInternal rather than predictPairInternal.
+#'
 #' @export
 heuristicsList <- function(list_of_fitted_heuristics, fn) {
   implementers <- list_of_fitted_heuristics
-  # Assume the cols_to_fit are the same for all heuristics.
   cols_to_fit <- implementers[[1]]$cols_to_fit
+
   # If no fit_name is set, use the first-level class as the name.
   # e.g. Regression has class [regModel, lm], so it will use regModel.
   names <- sapply(implementers, function(implementer) {
+    if (! isTRUE(all.equal(cols_to_fit, implementer$cols_to_fit)) ) {
+      col_str1 <- paste(cols_to_fit, collapse=", ")
+      col_str2 <- paste(implementer$cols_to_fit, collapse=", ")
+      stop(paste("ERROR: Models with different cols_to_fit:", col_str1,
+                 "vs.", col_str2, ".  Instead, put the models in separate",
+                 "heuristics functions, as shown in documentation examples."))
+
+      }
       if (is.null(implementer$fit_name)) {
         return(c(class(implementer)[[1]]))
       } else {
@@ -112,28 +150,54 @@ heuristicsList <- function(list_of_fitted_heuristics, fn) {
 
 #' Wrap fitted heuristics to pass to rowPairApply to call predictPair.
 #' 
-#' One or more fitted heuristics can be passed in.  They must all implement
-#' predictPairInternal.  Users will generally not use the output directly
-#' but instead pass this to rowPairApply.
+#' One or more fitted heuristics can be passed in.  They must all have the
+#' same cols_to_fit.  If they differ on cols_to_fit, then group them in separate
+#' heuristics functions.
+#' 
+#' Users will generally not use the output directly but instead pass this to
+#' rowPairApply.
 #' 
 #' @param ... A list of predictPairInternal implementers, e.g. a fitted ttb model.
 #' @return An object of class heuristics, which implements createFunction.
 #'   Users will generally not use this directly-- rowPairApply will.
 #'
 #' @examples
-#' ## This is typical usage:
+#' # Use one fitted ttbModel with column 1 as criterion and columns 2,3 as
+#' # cues.
 #' data <- cbind(y=c(30,20,10,5), x1=c(1,1,0,0), x2=c(1,1,0,1))
-#' ttb <- ttbModel(data, 1, c(2:ncol(data)))
+#' ttb <- ttbModel(data, 1, c(2:3))
 #' rowPairApply(data, heuristics(ttb))
-#' ## This outputs ttb's predictions for all 6 row pairs of data.
-#' ## (It has 6 row pairs because 4*2/2 = 6.)  It gets the predictions
-#' ## by calling ttb's predictPairInternal.
-#' 
+#' # This outputs ttb's predictions for all 6 row pairs of data.
+#' # (It has 6 row pairs because 4*2/2 = 6.)  It gets the predictions
+#' # by calling ttb's predictPairInternal.
+#'
+#' # Use the same fitted ttbModel plus a unit weight model with the same
+#' # criterion and cues.
+#' unit <- unitWeightModel(data, 1, c(2,3))
+#' rowPairApply(data, heuristics(ttb, unit))
+#' # This outputs predictions with column names 'ttbModel' and
+#' # 'unitWeightLinearModel'.
+#'
+#' # Use the same fitted ttbModel plus another ttbModel that has different
+#' # cols_to_fit.  This has to be put in a separate heuristicsList function.
+#' ttb_just_col_3 <- ttbModel(data, 1, c(3), fit_name="ttb3")
+#' rowPairApply(data, heuristics(ttb), heuristics(unit))
+#' # This outputs predictions with column names 'ttbModel' and
+#' # 'ttb3'.
+#'
 #' @seealso
-#' \code{\link{rowPairApply}} which is what heuristicsProb is passed in to.
+#' \code{\link{rowPairApply}} which is what the output of heuristics is
+#' normally passed in to.
+#'
+#' @seealso
+#' \code{\link{heuristicsList}} for a version of this function where you can
+#' control the function called (not necessarily predictPairInternal).
+#'
 #' @seealso
 #' \code{\link{predictPairInternal}} which must be implemented by heuristics in
-#'    order to use them with the heuristics() wrapper function.
+#' order to use them with the heuristics() wrapper function.  This only
+#' matters for people implementing their own heuristics.
+#'
 #' @export
 heuristics <- function(...) {
   implementers <- list(...)
